ocr

package
v0.0.0-...-0c97146 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Handle reading data from a provided document using OCR

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConvertToGray

func ConvertToGray(imgData []byte) *image.Gray

Convert an image.Image to image.Gray to access the SubImage method

func ReadRegion

func ReadRegion(img *image.Gray, r image.Rectangle) (string, error)

For a provided item, read and return the OCR'd data

Types

This section is empty.

Jump to