structs

package
v0.0.0-...-0c97146 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: MIT Imports: 2 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DocumentRegion

type DocumentRegion struct {
	RegionTitle string          `json:"region_title"`
	FieldName   string          `json:"data_field"`
	Region      image.Rectangle `json:"region"`
}

func (*DocumentRegion) IsValid

func (d *DocumentRegion) IsValid() bool

type DocumentType

type DocumentType struct {
	Title      string           `json:"title"`
	Identifier string           `json:"identifier"`
	Regions    []DocumentRegion `json:"regions"`
}

func (*DocumentType) IsValid

func (d *DocumentType) IsValid() bool

type ReqDeleteDocumentType

type ReqDeleteDocumentType struct {
	DocumentType string `json:"document_type"`
}

Struct for the Request to the server to delete a Document Type

type ReqRetrieveItem

type ReqRetrieveItem struct {
	ItemName string `json:"item_name"`
}

Struct for the Request

type RspGetDocumentTypes

type RspGetDocumentTypes struct {
	DocumentTypes []DocumentType `json:"document_types"`
}

Struct for the Response to a request for listing configured Document Types

type RspGetItems

type RspGetItems struct {
	Items []string `json:"items"`
}

Struct for the Response to a request for listing currently processed Items

type RspRetrieveItem

type RspRetrieveItem struct {
	Fields  map[string]string `json:"fields"`
	ImgData []byte            `json:"img_data"`
}

Jump to